# !/usr/bin/python3
# -*- coding: utf-8 -*-
from confapp import conf
from AnyQt.QtGui import QIcon

from pge_plugin_terminal.terminal_window import TerminalWindow

class ProjectsTerminal(object):

	def register_on_main_menu(self, mainmenu):
		super(ProjectsTerminal, self).register_on_main_menu(mainmenu)

		menu_index = 0
		for i, m in enumerate(mainmenu):
			if 'Window' in m.keys(): menu_index=i; break

		mainmenu[menu_index]['Window'].append( '-' )	
		mainmenu[menu_index]['Window'].append( {'Terminal': self.open_terminal_plugin, 'icon': conf.TERMINAL_PLUGIN_ICON} )
	
	def open_terminal_plugin(self):
		if not hasattr(self, 'terminal_plugin'):
			self.terminal_plugin = TerminalWindow(self)
			self.terminal_plugin.show()
			self.terminal_plugin.subwindow.resize(*conf.TERMINAL_PLUGIN_WINDOW_SIZE)			
		else:
			self.terminal_plugin.show()

		return self.terminal_plugin


# !/usr/bin/python3
# -*- coding: utf-8 -*-

""" session_window.py

"""

import logging, sys, io, traceback
from confapp import conf
from pyforms.basewidget import BaseWidget
from pyforms.controls import ControlButton
from pyforms.controls import ControlText
from pyforms.controls import ControlTextArea
from pyforms.controls import ControlList

from confapp import conf

from AnyQt import QtCore
from AnyQt.QtWidgets import QFileDialog


logger = logging.getLogger(__name__)


class TerminalWindow(BaseWidget):
	""" ProjectWindow represents the project entity as a GUI window"""

	def __init__(self, projects):
		BaseWidget.__init__(self, 'Terminal')

		self.projects  = projects

		self._log      = ControlList()
		self._command  = ControlText('Command')
		self._exec_script_btn = ControlButton('Open & run a script')

		self._formset = [
			'_log',
			('_command', '_exec_script_btn')
		]

		self._log.word_wrap = True
		self._log.readOnly = True
		self._command.key_pressed_event = self.__command_key_pressed_evt

		self._exec_script_btn.value = self.open_and_run_script


	def open_and_run_script(self, filepath=None, extra_args={}):
		if not filepath:
			filepath = QFileDialog.getOpenFileName(self, 'OpenFile')
		if filepath:

			sys.stdout 				 = io.StringIO()
			self._locals['projects']  = self.projects
			self._locals.update(extra_args)
			try:
				self._log += (">> EXECUTE SCRIPT: {0}".format(filepath), )
				with open(filepath) as f:
					code = compile(f.read(), filepath, 'exec')
					exec(code, self._globals, self._locals)
			except:
				print(traceback.format_exc(),)
				
			self._log +=  (sys.stdout.getvalue(), )
			sys.stdout = sys.__stdout__

			self._log.resize_rows_contents()

		
	def show(self):
		# Prevent the call to be recursive because of the mdi_area
		if hasattr(self, '_show_called'):
			BaseWidget.show(self)
			return
		self._show_called = True
		self.mainwindow.mdi_area += self
		del self._show_called

		self._locals = locals()
		self._globals = globals()

	def beforeClose(self):	return False

	@property
	def mainwindow(self): return self.projects.mainwindow

	def execute_script(self, code, locals_vars, globals_vars):
		sys.stdout 				 = io.StringIO()
		locals_vars['projects']  = self.projects
		try:
			for line in code.split('\n'): 
				self._log += (">> {0}".format(line), )				
				exec(line, globals_vars, locals_vars)
		except:
			print(traceback.format_exc(),)
			
		self._log +=  (sys.stdout.getvalue(), )
		sys.stdout = sys.__stdout__

		self._log.resize_rows_contents()


	def __command_key_pressed_evt(self, event):
		if event.key() == QtCore.Qt.Key_Return:
			self.execute_script(self._command.value, self._locals, self._globals )
			self._command.value = ''



#!/usr/bin/python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import re

version = ''
with open('pge_plugin_terminal/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')


setup(
    name='pge-plugin-terminal',
    version=version,
    description=""" Pyforms Generic Editor Terminal Plugin""",
    author='Ricardo Jorge Vieira Ribeiro',
    author_email='ricardojvr@gmail.com',
    license='Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>',
    url='https://bitbucket.org/fchampalimaud/pycontrol-gui-plugin-terminal',

    include_package_data=True,
    packages=find_packages(exclude=['contrib', 'docs', 'tests', 'examples', 'deploy', 'reports']),

    package_data={'pge_plugin_terminal': [
            'resources/*.*',
        ]
    },
)
